@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::NumericLevel;
 
-our $DATE = '2021-01-31'; # DATE
-our $VERSION = '0.017'; # VERSION
+our $DATE = '2021-04-09'; # DATE
+our $VERSION = '0.018'; # VERSION
 
 use 5.010001;
 use strict;
@@ -35,7 +35,7 @@ Bencher::Scenario::LogGer::NumericLevel - Benchmark numeric_level()
 
 =head1 VERSION
 
-This document describes version 0.017 of Bencher::Scenario::LogGer::NumericLevel (from Perl distribution Bencher-Scenarios-LogGer), released on 2021-01-31.
+This document describes version 0.018 of Bencher::Scenario::LogGer::NumericLevel (from Perl distribution Bencher-Scenarios-LogGer), released on 2021-04-09.
 
 =head1 SYNOPSIS
 
@@ -85,28 +85,28 @@ Function call template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.30.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux LinuxMint version 19 >>, OS kernel: I<< Linux version 5.3.0-68-generic >>.
+Run on: perl: I<< v5.30.0 >>, CPU: I<< Intel(R) Core(TM) i5-7200U CPU @ 2.50GHz (2 cores) >>, OS: I<< GNU/Linux Ubuntu version 20.04 >>, OS kernel: I<< Linux version 5.3.0-64-generic >>.
 
 Benchmark with default options (C<< bencher -m LogGer::NumericLevel >>):
 
  #table1#
- +---------+-----------+-----------+-----------------------+-----------------------+--------+---------+
- | dataset | rate (/s) | time (ns) | pct_faster_vs_slowest | pct_slower_vs_fastest | errors | samples |
- +---------+-----------+-----------+-----------------------+-----------------------+--------+---------+
- | warn    |   3585860 |   278.873 |                 0.00% |                18.20% |      0 |      20 |
- | 10      |   4238380 |   235.939 |                18.20% |                 0.00% |      0 |      20 |
- +---------+-----------+-----------+-----------------------+-----------------------+--------+---------+
+ +---------+-----------+-----------+-----------------------+-----------------------+---------+---------+
+ | dataset | rate (/s) | time (ns) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
+ +---------+-----------+-----------+-----------------------+-----------------------+---------+---------+
+ | warn    |   2970000 |       337 |                 0.00% |                20.53% | 1.1e-10 |      20 |
+ | 10      |   3580000 |       279 |                20.53% |                 0.00% |   1e-10 |      20 |
+ +---------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m LogGer::NumericLevel --module-startup >>):
 
  #table2#
- +---------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
- | participant         | time (ms) | mod_overhead_time | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors   | samples |
- +---------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
- | Log::ger::Util      |         9 |                 3 |                 0.00% |                55.50% |   0.00024 |      21 |
- | perl -e1 (baseline) |         6 |                 0 |                55.50% |                 0.00% | 8.1e-05   |      20 |
- +---------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
+ +---------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
+ | participant         | time (ms) | mod_overhead_time | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
+ +---------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
+ | Log::ger::Util      |      12   |               4.1 |                 0.00% |                50.40% | 1.7e-05 |      21 |
+ | perl -e1 (baseline) |       7.9 |               0   |                50.40% |                 0.00% | 1.3e-05 |      20 |
+ +---------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
@@ -121,7 +121,7 @@ Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-Lo
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-LogGer>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Bencher-Scenarios-LogGer/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
