@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::OutputStartup;
 
-our $DATE = '2021-01-31'; # DATE
-our $VERSION = '0.017'; # VERSION
+our $DATE = '2021-04-09'; # DATE
+our $VERSION = '0.018'; # VERSION
 
 use 5.010001;
 use strict;
@@ -75,7 +75,7 @@ Bencher::Scenario::LogGer::OutputStartup
 
 =head1 VERSION
 
-This document describes version 0.017 of Bencher::Scenario::LogGer::OutputStartup (from Perl distribution Bencher-Scenarios-LogGer), released on 2021-01-31.
+This document describes version 0.018 of Bencher::Scenario::LogGer::OutputStartup (from Perl distribution Bencher-Scenarios-LogGer), released on 2021-04-09.
 
 =head1 SYNOPSIS
 
@@ -103,7 +103,7 @@ L<Log::ger::Output::ArrayRotate> 0.004
 
 L<Log::ger::Output::Callback> 0.009
 
-L<Log::ger::Output::Composite> 0.016
+L<Log::ger::Output::Composite> 0.017
 
 L<Log::ger::Output::DirWriteRotate> 0.004
 
@@ -115,7 +115,7 @@ L<Log::ger::Output::LogAny> 0.009
 
 L<Log::ger::Output::Null> 0.038
 
-L<Log::ger::Output::Screen> 0.015
+L<Log::ger::Output::Screen> 0.017
 
 L<Log::ger::Output::String> 0.038
 
@@ -277,7 +277,7 @@ L<Log::ger::Output::Syslog>
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.30.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux LinuxMint version 19 >>, OS kernel: I<< Linux version 5.3.0-68-generic >>.
+Run on: perl: I<< v5.30.0 >>, CPU: I<< Intel(R) Core(TM) i5-7200U CPU @ 2.50GHz (2 cores) >>, OS: I<< GNU/Linux Ubuntu version 20.04 >>, OS kernel: I<< Linux version 5.3.0-64-generic >>.
 
 Benchmark with default options (C<< bencher -m LogGer::OutputStartup >>):
 
@@ -285,31 +285,31 @@ Benchmark with default options (C<< bencher -m LogGer::OutputStartup >>):
  +---------------------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
  | participant               | rate (/s) | time (ms) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors   | samples |
  +---------------------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
- | init-with-FileWriteRotate |        29 |      34   |                 0.00% |               574.52% | 6.4e-05   |      20 |
- | init-with-Syslog          |        40 |      25   |                37.83% |               389.37% |   0.00015 |      21 |
- | init-with-Composite       |        45 |      22   |                53.57% |               339.22% |   0.00019 |      20 |
- | init-with-File            |        55 |      18   |                86.51% |               261.65% | 8.3e-05   |      20 |
- | init-with-LogAny          |        66 |      15   |               123.64% |               201.62% |   0.00015 |      20 |
- | load-File                 |        71 |      14   |               141.15% |               179.71% | 4.7e-05   |      20 |
- | init-with-DirWriteRotate  |        82 |      12   |               178.29% |               142.38% | 5.2e-05   |      20 |
- | init-with-String          |        90 |      10   |               191.78% |               131.18% |   0.00026 |      20 |
- | init-with-Array           |        90 |      10   |               199.05% |               125.55% |   0.00019 |      21 |
- | init-with-Callback        |        90 |      10   |               208.14% |               118.90% |   0.0002  |      20 |
- | load-Composite            |        90 |      10   |               208.93% |               118.34% |   0.00032 |      20 |
- | init-with-Screen          |        90 |      10   |               210.69% |               117.10% |   0.00012 |      20 |
- | init-with-Null            |        90 |      10   |               217.38% |               112.53% |   0.00021 |      20 |
- | load-Syslog               |       100 |       9.6 |               254.42% |                90.32% | 9.4e-05   |      20 |
- | load-Screen               |       100 |      10   |               258.19% |                88.32% |   0.00012 |      20 |
- | init-with-ArrayRotate     |       110 |       9.3 |               266.57% |                84.01% | 2.1e-05   |      23 |
- | load-String               |       100 |       8   |               344.26% |                51.83% |   0.00015 |      20 |
- | load-LogAny               |       100 |       8   |               347.04% |                50.89% |   8e-05   |      20 |
- | load-ArrayRotate          |       100 |       8   |               353.83% |                48.63% | 9.4e-05   |      20 |
- | load-Array                |       100 |       7   |               356.37% |                47.80% | 9.2e-05   |      20 |
- | load-DirWriteRotate       |       100 |       7   |               364.97% |                45.07% |   0.0002  |      20 |
- | load-FileWriteRotate      |       100 |       7   |               369.74% |                43.59% |   0.00012 |      21 |
- | load-Null                 |       200 |       6   |               446.19% |                23.50% | 7.8e-05   |      20 |
- | load-Callback             |       170 |       5.8 |               486.76% |                14.96% | 5.7e-05   |      20 |
- | baseline                  |       200 |       5   |               574.52% |                 0.00% |   0.00019 |      20 |
+ | init-with-FileWriteRotate |      24.5 |      40.8 |                 0.00% |               419.66% | 3.2e-05   |      20 |
+ | init-with-Syslog          |      30   |      30   |                22.84% |               323.05% |   0.00039 |      20 |
+ | init-with-Composite       |      37   |      27   |                49.99% |               246.46% |   0.00017 |      20 |
+ | init-with-LogAny          |      50   |      20   |                85.65% |               179.91% |   0.00052 |      21 |
+ | init-with-File            |      46   |      22   |                88.04% |               176.35% | 3.9e-05   |      20 |
+ | load-File                 |      55   |      18   |               126.03% |               129.90% | 2.7e-05   |      20 |
+ | init-with-String          |      60   |      20   |               139.06% |               117.38% |   0.00031 |      20 |
+ | init-with-DirWriteRotate  |      59   |      17   |               142.60% |               114.20% | 4.5e-05   |      20 |
+ | load-Syslog               |      70   |      20   |               167.55% |                94.22% |   0.00021 |      21 |
+ | init-with-ArrayRotate     |      70   |      20   |               169.45% |                92.86% |   0.0002  |      20 |
+ | init-with-Callback        |      70   |      14   |               185.99% |                81.70% | 2.9e-05   |      21 |
+ | init-with-Screen          |      71   |      14   |               187.77% |                80.58% | 2.4e-05   |      21 |
+ | init-with-Array           |      71   |      14   |               189.04% |                79.79% | 4.7e-05   |      20 |
+ | init-with-Null            |      73.1 |      13.7 |               198.08% |                74.34% | 1.2e-05   |      20 |
+ | load-Composite            |      76   |      13   |               208.29% |                68.56% | 4.5e-05   |      20 |
+ | load-Screen               |      77   |      13   |               214.36% |                65.31% | 6.7e-05   |      20 |
+ | load-ArrayRotate          |      80   |      10   |               235.24% |                55.01% |   0.00022 |      20 |
+ | load-DirWriteRotate       |      98   |      10   |               298.64% |                30.36% | 9.5e-05   |      23 |
+ | load-Array                |     100   |       9.7 |               320.40% |                23.61% | 2.9e-05   |      20 |
+ | load-FileWriteRotate      |     100   |       9.6 |               323.18% |                22.80% | 2.6e-05   |      20 |
+ | load-String               |     100   |       9.6 |               325.47% |                22.14% | 1.4e-05   |      20 |
+ | load-Callback             |     100   |       9.6 |               325.63% |                22.09% | 2.5e-05   |      20 |
+ | load-LogAny               |     100   |       9.6 |               325.84% |                22.03% | 3.6e-05   |      20 |
+ | load-Null                 |     120   |       8.1 |               401.85% |                 3.55% | 1.1e-05   |      20 |
+ | baseline                  |     130   |       7.8 |               419.66% |                 0.00% |   4e-05   |      22 |
  +---------------------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
 
 
@@ -319,19 +319,19 @@ Benchmark module startup overhead (C<< bencher -m LogGer::OutputStartup --module
  +-----------------------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
  | participant                       | time (ms) | mod_overhead_time | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors   | samples |
  +-----------------------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
- | Log::ger::Output::File            |      10   |               5.9 |                 0.00% |               253.84% |   0.00024 |      20 |
- | Log::ger::Output::Composite       |      10   |               5.9 |                39.51% |               153.63% |   0.00021 |      20 |
- | Log::ger::Output::Screen          |       9.1 |               5   |                58.60% |               123.10% | 4.3e-05   |      20 |
- | Log::ger::Output::Syslog          |       8.9 |               4.8 |                62.56% |               117.67% | 2.1e-05   |      20 |
- | Log::ger::Output::Callback        |       7.8 |               3.7 |                86.51% |                89.71% | 6.7e-05   |      20 |
- | Log::ger::Output::ArrayRotate     |       7.6 |               3.5 |                89.42% |                86.80% | 7.1e-05   |      20 |
- | Log::ger::Output::DirWriteRotate  |       8   |               3.9 |                90.59% |                85.65% |   0.00016 |      20 |
- | Log::ger::Output::LogAny          |       7   |               2.9 |                93.05% |                83.29% |   0.00015 |      20 |
- | Log::ger::Output::FileWriteRotate |       7   |               2.9 |               100.38% |                76.58% | 8.6e-05   |      21 |
- | Log::ger::Output::String          |       6.4 |               2.3 |               125.43% |                56.96% | 3.5e-05   |      20 |
- | Log::ger::Output::Null            |       6   |               1.9 |               128.71% |                54.71% | 7.5e-05   |      20 |
- | Log::ger::Output::Array           |       6.2 |               2.1 |               134.85% |                50.67% | 2.8e-05   |      23 |
- | perl -e1 (baseline)               |       4.1 |               0   |               253.84% |                 0.00% | 3.6e-05   |      20 |
+ | Log::ger::Output::File            |      20   |              12   |                 0.00% |               157.86% |   0.00028 |      22 |
+ | Log::ger::Output::Composite       |      13   |               5   |                57.70% |                63.51% |   2e-05   |      20 |
+ | Log::ger::Output::Screen          |      12   |               4   |                67.62% |                53.84% | 2.1e-05   |      20 |
+ | Log::ger::Output::Syslog          |      12.2 |               4.2 |                70.24% |                51.47% | 1.1e-05   |      20 |
+ | Log::ger::Output::LogAny          |      10   |               2   |                98.10% |                30.17% | 7.6e-05   |      20 |
+ | Log::ger::Output::FileWriteRotate |      10   |               2   |               106.36% |                24.96% | 6.4e-05   |      20 |
+ | Log::ger::Output::DirWriteRotate  |       9.8 |               1.8 |               111.55% |                21.89% | 1.8e-05   |      23 |
+ | Log::ger::Output::Array           |       9.8 |               1.8 |               111.64% |                21.84% | 1.3e-05   |      20 |
+ | Log::ger::Output::Callback        |       9.8 |               1.8 |               111.73% |                21.79% | 1.2e-05   |      21 |
+ | Log::ger::Output::String          |       9.7 |               1.7 |               113.89% |                20.56% | 3.2e-05   |      20 |
+ | Log::ger::Output::ArrayRotate     |       9.7 |               1.7 |               114.16% |                20.41% | 2.8e-05   |      20 |
+ | Log::ger::Output::Null            |       8.5 |               0.5 |               144.87% |                 5.31% | 4.8e-05   |      20 |
+ | perl -e1 (baseline)               |       8   |               0   |               157.86% |                 0.00% | 8.1e-06   |      20 |
  +-----------------------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
 
 
@@ -347,7 +347,7 @@ Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-Lo
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-LogGer>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Bencher-Scenarios-LogGer/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
