@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::Overhead;
 
-our $DATE = '2021-01-31'; # DATE
-our $VERSION = '0.017'; # VERSION
+our $DATE = '2021-04-09'; # DATE
+our $VERSION = '0.018'; # VERSION
 
 use 5.010001;
 use strict;
@@ -26,6 +26,7 @@ our $scenario = {
         'Log::Log4perl::Tiny' => {version=>'0'},
         'Log::Dispatchouli' => {version=>'0'},
         'Mojo::Log' => {version=>'0'},
+        'XLog' => {},
     },
     code_startup => 1,
     participants => [
@@ -64,6 +65,8 @@ our $scenario = {
         {code_template=>'use Mojo::Log;'},
         {code_template=>'use Mojo::Log; my $log=Mojo::Log->new(level=>"warn")'},
 
+        {code_template=>'use XLog;'},
+
         # TODO: Lg + Composite (2 outputs)
         # TODO: Lg + Composite (2 outputs + pattern layouts)
         # TODO: Log::Any + Screen
@@ -86,7 +89,7 @@ Bencher::Scenario::LogGer::Overhead - Measure startup overhead of various codes
 
 =head1 VERSION
 
-This document describes version 0.017 of Bencher::Scenario::LogGer::Overhead (from Perl distribution Bencher-Scenarios-LogGer), released on 2021-01-31.
+This document describes version 0.018 of Bencher::Scenario::LogGer::Overhead (from Perl distribution Bencher-Scenarios-LogGer), released on 2021-04-09.
 
 =head1 SYNOPSIS
 
@@ -108,13 +111,13 @@ L<Log::Any> 1.708
 
 L<Log::Contextual> 0.008001
 
-L<Log::Dispatch> 2.70
+L<Log::Dispatch> 2.68
 
-L<Log::Dispatch::Null> 2.70
+L<Log::Dispatch::Null> 2.68
 
-L<Log::Dispatchouli> 2.022
+L<Log::Dispatchouli> 2.019
 
-L<Log::Log4perl> 1.53
+L<Log::Log4perl> 1.49
 
 L<Log::Log4perl::Tiny> 1.4.0
 
@@ -128,6 +131,8 @@ L<Log::ger::Output> 0.038
 
 L<Mojo::Log>
 
+L<XLog> 1.1.0
+
 =head1 BENCHMARK PARTICIPANTS
 
 =over
@@ -324,42 +329,51 @@ Code template:
 
 
 
+=item * use XLog; (perl_code)
+
+Code template:
+
+ use XLog;
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.30.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux LinuxMint version 19 >>, OS kernel: I<< Linux version 5.3.0-68-generic >>.
+Run on: perl: I<< v5.30.0 >>, CPU: I<< Intel(R) Core(TM) i5-7200U CPU @ 2.50GHz (2 cores) >>, OS: I<< GNU/Linux Ubuntu version 20.04 >>, OS kernel: I<< Linux version 5.3.0-64-generic >>.
 
 Benchmark with default options (C<< bencher -m LogGer::Overhead >>):
 
  #table1#
  +------------------------------------------------------------------+-----------+---------------------+-----------------------+-----------------------+-----------+---------+
- | participant                                                      | time (ms) |  code_overhead_time | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors   | samples |
+ | participant                                                      | time (ms) | code_overhead_time  | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors   | samples |
  +------------------------------------------------------------------+-----------+---------------------+-----------------------+-----------------------+-----------+---------+
- | use Mojo::Log; my $log=Mojo::Log->new(level=>"warn")             |      85   | 80                  |                 0.00% |              1719.57% |   0.00017 |      24 |
- | use Mojo::Log;                                                   |      84   | 79                  |                 1.00% |              1701.58% |   0.00019 |      20 |
- | use Log::Dispatchouli;                                           |      67   | 62                  |                27.26% |              1329.84% |   0.00017 |      21 |
- | use Log::Dispatch; my $null = Log::Dispatch->new(outputs=>[ ["Nu |      64   | 59                  |                32.79% |              1270.24% |   0.00011 |      20 |
- | use Log::Dispatch;                                               |      60   | 55                  |                41.57% |              1185.27% |   0.00011 |      20 |
- | use Log::Contextual qw(:log);                                    |      57   | 52                  |                49.72% |              1115.33% | 9.9e-05   |      20 |
- | use Log::Log4perl;                                               |      29   | 24                  |               192.80% |               521.43% | 9.2e-05   |      20 |
- | use Log::ger::App; use Log::ger;                                 |      23   | 18                  |               263.20% |               400.98% | 6.9e-05   |      21 |
- | use Log::ger::App;                                               |      19   | 14                  |               348.71% |               305.51% | 3.8e-05   |      21 |
- | use Log::Log4perl::Tiny;                                         |      20   | 15                  |               446.58% |               232.90% |   0.00017 |      20 |
- | use Log::ger::Like::Log4perl;                                    |      13   |  8                  |               539.05% |               184.73% | 3.5e-05   |      21 |
- | use Log::Any q($log);                                            |      10   |  5                  |               641.14% |               145.51% |   0.00025 |      20 |
- | use Log::Any;                                                    |      11   |  6                  |               688.89% |               130.65% | 6.1e-05   |      22 |
- | use Log::ger::Output::Composite;                                 |      10   |  5                  |               724.33% |               120.73% |   0.00027 |      20 |
- | use Log::ger::Output::Screen;                                    |      10   |  5                  |               733.20% |               118.38% |   0.00021 |      20 |
- | use warnings;                                                    |       8   |  3                  |              1019.12% |                62.59% |   0.00012 |      20 |
- | use Log::ger::Plugin::OptAway; use Log::ger;                     |       7.2 |  2.2                |              1083.39% |                53.76% | 2.8e-05   |      23 |
- | use strict;                                                      |       7   |  2                  |              1208.49% |                39.06% | 9.5e-05   |      20 |
- | use strict; use warnings;                                        |       6   |  1                  |              1322.64% |                27.90% | 2.6e-05   |      20 |
- | use Log::ger::Like::LogAny;                                      |       5.4 |  0.4                |              1471.83% |                15.76% | 4.5e-05   |      21 |
- | use Log::ger;                                                    |       5   |  0                  |              1588.19% |                 7.78% | 7.6e-05   |      20 |
- | use Log::ger ();                                                 |       4.9 | -0.0999999999999996 |              1650.50% |                 3.95% | 2.7e-05   |      20 |
- | perl -e1 (baseline)                                              |       5   |  0                  |              1656.78% |                 3.57% | 7.1e-05   |      20 |
- | use Log::ger; Log::ger->get_logger;                              |       4.7 | -0.3                |              1719.57% |                 0.00% | 1.7e-05   |      21 |
+ | use Mojo::Log;                                                   |    110    | 102                 |                 0.00% |              1222.58% |   0.00026 |      20 |
+ | use Mojo::Log; my $log=Mojo::Log->new(level=>"warn")             |    105    |  97                 |                 0.78% |              1212.35% |   4e-05   |      20 |
+ | use Log::Dispatchouli;                                           |     85    |  77                 |                24.66% |               960.99% |   0.00045 |      20 |
+ | use Log::Dispatch; my $null = Log::Dispatch->new(outputs=>[ ["Nu |     81    |  73                 |                31.32% |               907.18% |   0.00023 |      21 |
+ | use Log::Dispatch;                                               |     73.4  |  65.4               |                44.11% |               817.75% |   5e-05   |      20 |
+ | use Log::Contextual qw(:log);                                    |     71    |  63                 |                48.71% |               789.38% |   0.00024 |      20 |
+ | use Log::Log4perl;                                               |     36    |  28                 |               193.56% |               350.53% |   0.0001  |      20 |
+ | use Log::ger::App; use Log::ger;                                 |     29    |  21                 |               267.84% |               259.56% | 4.6e-05   |      20 |
+ | use Log::ger::App;                                               |     24    |  16                 |               343.30% |               198.35% | 2.7e-05   |      20 |
+ | use XLog;                                                        |     24    |  16                 |               344.67% |               197.43% | 2.5e-05   |      20 |
+ | use Log::Log4perl::Tiny;                                         |     20    |  12                 |               438.17% |               145.75% | 3.6e-05   |      20 |
+ | use Log::ger::Like::Log4perl;                                    |     17    |   9                 |               508.84% |               117.23% | 4.2e-05   |      20 |
+ | use Log::Any q($log);                                            |     20    |  12                 |               561.57% |                99.92% |   0.00021 |      20 |
+ | use Log::Any;                                                    |     14    |   6                 |               647.20% |                77.01% |   2e-05   |      20 |
+ | use Log::ger::Output::Composite;                                 |     12.9  |   4.9               |               716.92% |                61.90% | 6.6e-06   |      21 |
+ | use Log::ger::Output::Screen;                                    |     12    |   4                 |               758.44% |                54.07% | 1.3e-05   |      20 |
+ | use Log::ger::Plugin::OptAway; use Log::ger;                     |     10.1  |   2.1               |               949.31% |                26.04% | 9.2e-06   |      21 |
+ | use strict; use warnings;                                        |      9.5  |   1.5               |              1017.17% |                18.39% |   3e-05   |      20 |
+ | use warnings;                                                    |      9.2  |   1.2               |              1053.37% |                14.67% |   3e-05   |      20 |
+ | use Log::ger::Like::LogAny;                                      |      8.9  |   0.9               |              1093.42% |                10.82% | 2.5e-05   |      20 |
+ | use Log::ger; Log::ger->get_logger;                              |      8.6  |   0.6               |              1130.54% |                 7.48% | 2.5e-05   |      20 |
+ | use Log::ger;                                                    |      8.5  |   0.5               |              1143.82% |                 6.33% | 1.7e-05   |      20 |
+ | use Log::ger ();                                                 |      8.5  |   0.5               |              1147.98% |                 5.98% | 2.4e-05   |      20 |
+ | use strict;                                                      |      8.45 |   0.449999999999999 |              1151.79% |                 5.66% | 6.2e-06   |      20 |
+ | perl -e1 (baseline)                                              |      8    |   0                 |              1222.58% |                 0.00% | 1.6e-05   |      20 |
  +------------------------------------------------------------------+-----------+---------------------+-----------------------+-----------------------+-----------+---------+
 
 
@@ -375,7 +389,7 @@ Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-Lo
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-LogGer>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Bencher-Scenarios-LogGer/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
