@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::StringLevel;
 
-our $DATE = '2021-01-31'; # DATE
-our $VERSION = '0.017'; # VERSION
+our $DATE = '2021-04-09'; # DATE
+our $VERSION = '0.018'; # VERSION
 
 use 5.010001;
 use strict;
@@ -38,7 +38,7 @@ Bencher::Scenario::LogGer::StringLevel - Benchmark string_level()
 
 =head1 VERSION
 
-This document describes version 0.017 of Bencher::Scenario::LogGer::StringLevel (from Perl distribution Bencher-Scenarios-LogGer), released on 2021-01-31.
+This document describes version 0.018 of Bencher::Scenario::LogGer::StringLevel (from Perl distribution Bencher-Scenarios-LogGer), released on 2021-04-09.
 
 =head1 SYNOPSIS
 
@@ -88,7 +88,7 @@ Function call template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.30.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux LinuxMint version 19 >>, OS kernel: I<< Linux version 5.3.0-68-generic >>.
+Run on: perl: I<< v5.30.0 >>, CPU: I<< Intel(R) Core(TM) i5-7200U CPU @ 2.50GHz (2 cores) >>, OS: I<< GNU/Linux Ubuntu version 20.04 >>, OS kernel: I<< Linux version 5.3.0-64-generic >>.
 
 Benchmark with default options (C<< bencher -m LogGer::StringLevel >>):
 
@@ -96,8 +96,8 @@ Benchmark with default options (C<< bencher -m LogGer::StringLevel >>):
  +---------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | dataset | rate (/s) | time (ns) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +---------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | 10      |   1100000 |       930 |                 0.00% |               541.01% | 1.2e-09 |      20 |
- | warn    |   6860000 |       146 |               541.01% |                 0.00% | 5.2e-11 |      20 |
+ | 10      |    888700 |      1125 |                 0.00% |               624.43% | 2.3e-11 |      20 |
+ | warn    |   6440000 |       155 |               624.43% |                 0.00% | 2.3e-11 |      20 |
  +---------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
 
@@ -107,8 +107,8 @@ Benchmark module startup overhead (C<< bencher -m LogGer::StringLevel --module-s
  +---------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
  | participant         | time (ms) | mod_overhead_time | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +---------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
- | Log::ger::Util      |       7.7 |               4.5 |                 0.00% |               138.14% | 2.4e-05 |      21 |
- | perl -e1 (baseline) |       3.2 |               0   |               138.14% |                 0.00% | 1.1e-05 |      20 |
+ | Log::ger::Util      |      11.9 |               4.1 |                 0.00% |                52.46% | 1.1e-05 |      20 |
+ | perl -e1 (baseline) |       7.8 |               0   |                52.46% |                 0.00% | 2.1e-05 |      20 |
  +---------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
 
 
@@ -124,7 +124,7 @@ Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-Lo
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-LogGer>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Bencher-Scenarios-LogGer/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
