@@ -1,7 +1,7 @@
 package Bencher::Scenarios::LogGer;
 
-our $DATE = '2021-01-31'; # DATE
-our $VERSION = '0.017'; # VERSION
+our $DATE = '2021-04-09'; # DATE
+our $VERSION = '0.018'; # VERSION
 
 1;
 # ABSTRACT: Scenarios for benchmarking Log::ger
@@ -18,7 +18,7 @@ Bencher::Scenarios::LogGer - Scenarios for benchmarking Log::ger
 
 =head1 VERSION
 
-This document describes version 0.017 of Bencher::Scenarios::LogGer (from Perl distribution Bencher-Scenarios-LogGer), released on 2021-01-31.
+This document describes version 0.018 of Bencher::Scenarios::LogGer (from Perl distribution Bencher-Scenarios-LogGer), released on 2021-04-09.
 
 =head1 DESCRIPTION
 
@@ -26,19 +26,19 @@ This distribution contains the following L<Bencher> scenario modules:
 
 =over
 
-=item * L<Bencher::Scenario::LogGer::LayoutStartup>
+=item * L<Bencher::Scenario::LogGer::InitTarget>
 
 =item * L<Bencher::Scenario::LogGer::NullOutput>
 
-=item * L<Bencher::Scenario::LogGer::Overhead>
+=item * L<Bencher::Scenario::LogGer::OutputStartup>
+
+=item * L<Bencher::Scenario::LogGer::NumericLevel>
+
+=item * L<Bencher::Scenario::LogGer::LayoutStartup>
 
 =item * L<Bencher::Scenario::LogGer::StringLevel>
 
-=item * L<Bencher::Scenario::LogGer::OutputStartup>
-
-=item * L<Bencher::Scenario::LogGer::InitTarget>
-
-=item * L<Bencher::Scenario::LogGer::NumericLevel>
+=item * L<Bencher::Scenario::LogGer::Overhead>
 
 =back
 
@@ -52,7 +52,7 @@ Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-Lo
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-LogGer>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Bencher-Scenarios-LogGer/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
